
'______________________________________________________
'  
'                            N E T D U I N O   M I N I
'                  BASIC SERVO CONTROL FOR BOE-BOT
'                                   VB VERSION
'                        .NET MICROFRAMEWORK 4.2
'                        
'                                   Ron Kessler
'                             Created 5/19/2013
'                    
' ______________________________________________________
'

'Requires .Net MicroFramework 4.2 installed on your computer along with Netduino SDK 4.2.2 or greater

'---take careful note of references I added. Make sure the properties show they are for NETMF 4.2.2 or greater
'Also, VS includes reference to MS.SPOT.PWM. Remove it!!!  Add a reference to SecretLabs.NETFW.Hardware,
'SecretLabs.NETFW.PWM and SecretLabs.NETFW.PWM

'To deploy the app to the bot, go into properties of the project and choose the .Net MicroFramework tab. Change the
'transport option to Serial and select the correct Com port so the program is loaded onto your machine.

Imports System
Imports System.Threading
Imports Microsoft.SPOT
Imports Microsoft.SPOT.Hardware
Imports SecretLabs.NETMF.Hardware
Imports SecretLabs.NETMF.Hardware.NetduinoMini

Module Module1

    Sub Main()
        
        '---define two pin numbers to send a pulse to each servo

        '---netduino mini can use pins 17-20 for PWM. This equates to pins numbered 12,13,14, & 15 on the BOE board. 
        'count the Netduino pins. Top left =1, bottom left =12, bottom rt = 13, top rt = 24.

        'Notice you match up the NM pin# with those printed on the BOE!
        'Netduino Mini goes in with two little chips facing the center of BOE towards battery. Tiny gold plate on NM = pin 12 (#7 on BOE)

        Dim leftServo As PWM = New PWM(Pins.GPIO_PIN_17)      'use pin 12 on BOE. This lets us use the regular servo connector and sockets on the board. No wiring!
        Dim rightServo As PWM = New PWM(Pins.GPIO_PIN_18)     'use pin 13 on BOE

        '---define period of the pulse timing. Every 20ms or 20000 microseconds (us)
        ' SetPulse requires values in microseconds(us)
        Dim period As UInt32 = 20000

        Dim counterClockwise As UInt32 = 1700
        Dim clockwise As UInt32 = 1300
        Dim botStop As UInt32 = 1500

       

        Do           'continuous loop


            '---forward
            leftServo.SetPulse(period, clockwise)                'clockwise
            rightServo.SetPulse(period, counterClockwise)   'counter-clockwise
            Thread.Sleep(4000)                                          'go for 4 seconds

            '---backwards
            leftServo.SetPulse(period, counterClockwise)      'counter-clockwise
            rightServo.SetPulse(period, clockwise)            'clockwise
            Thread.Sleep(4000)

            '---left turn
            leftServo.SetPulse(period, clockwise)                'both servos turn clockwise
            rightServo.SetPulse(period, clockwise)
            Thread.Sleep(4000)

            '---right turn
            leftServo.SetPulse(period, counterClockwise)      'both servos turn counter-clockwise
            rightServo.SetPulse(period, counterClockwise)
            Thread.Sleep(4000)

            '---stop before continuing
            leftServo.SetPulse(period, botStop)                 'both servos stop
            rightServo.SetPulse(period, botStop)
            Thread.Sleep(4000)
        Loop

    End Sub

End Module
